@@ -16,7 +16,8 @@ root_ca_file_name = "root-CA.crt"
 root_ca_file_path = os.path.join(cert_dir, root_ca_file_name)
 
 log_dir = "/var/log/vyomcloudbridge"
-log_file = os.path.join(log_dir, "vyomcloudbridge.log")
+log_file_name = "vyomcloudbridge.log"
+log_file = os.path.join(log_dir, log_file_name)
 pid_file = os.path.join(log_dir, "service_pids.json")
 machine_config_file = os.path.join(vyom_root_dir, "machine.conf")
 machine_topics_file = os.path.join(vyom_root_dir, "machine_topics.json")
