@@ -201,6 +201,10 @@ class ServiceManager:
             command = "missionstats"
         elif service_name == "machinestats":
             command = "machinestats"
+        elif service_name == "mavproxyhq":
+            command = "mavproxyhq"
+        elif service_name == "robotstat":
+            command = "robotstat"
 
         if name:
             command += f" --name {name}"
