@@ -51,6 +51,7 @@ class MachineStats(ServiceAbstract):
         self.root_store = RootStore()
         self.rabbit_mq_utils = RabbitMQUtils()
         self.rabbit_mq_api_sync_delay = 5  # seconds
+        self.destination_ids = ["s3", "gcs_mqtt"]
         # Thread attributes
         self.stats_thread = None
         self.is_running = False
@@ -297,7 +298,7 @@ class MachineStats(ServiceAbstract):
             headers = {
                 "topic": f"{mission_upload_dir}/{epoch_ms}.json",
                 "message_type": "json",
-                "destination_ids": ["s3"],
+                "destination_ids": self.destination_ids,
                 "data_source": self.data_source,
                 # meta data
                 "buffer_key": data_buffer_key,
