@@ -145,7 +145,7 @@ class MissionStats(ServiceAbstract):
             mission_id: The ID of the mission to set as last data
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             # Clear the queue first (get all messages)
@@ -179,7 +179,7 @@ class MissionStats(ServiceAbstract):
             The mission ID string or None if not found
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             # Get the message but don't acknowledge it initially
@@ -206,7 +206,7 @@ class MissionStats(ServiceAbstract):
         Args:
             mission_id: The ID of the mission to create a queue for
         """
-        if not self._ensure_connection():
+        if not self._ensure_connection() or not self.rmq_channel:
             raise Exception("Could not establish connection")
 
         if isinstance(mission_id, int):
@@ -235,7 +235,7 @@ class MissionStats(ServiceAbstract):
         queue_name = f"mission_stats_{mission_id}"
 
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             # Declare queue (will not do anything if it already exists)
@@ -298,7 +298,7 @@ class MissionStats(ServiceAbstract):
         queue_name = f"mission_stats_{mission_id}"
 
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             if isinstance(mission_id, int):
@@ -336,7 +336,7 @@ class MissionStats(ServiceAbstract):
             mission_id: The ID of the mission to delete
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             if isinstance(mission_id, int):
@@ -407,7 +407,7 @@ class MissionStats(ServiceAbstract):
                 "json_data": {},
             }
 
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             while True:
@@ -473,7 +473,7 @@ class MissionStats(ServiceAbstract):
                 - str or None: Error message if any issue occurs, else None
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 error_message = "Could not establish connection"
                 self.logger.error(error_message)
                 return None, error_message
@@ -575,7 +575,7 @@ class MissionStats(ServiceAbstract):
                 "json_data": {},
             }
 
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 error_message = "Could not establish connections, please try again"
                 return None, error_message
 
@@ -652,7 +652,7 @@ class MissionStats(ServiceAbstract):
                 if mission_detail.get("mission_status") == 1:
                     existing_mission_id = mission_detail.get("id")
                     mission_detail["mission_status"] = 2
-                    if not self._ensure_connection():
+                    if not self._ensure_connection() or not self.rmq_channel:
                         error_message = "Could not establish connection"
                         return False, error_message
 
@@ -808,9 +808,9 @@ class MissionStats(ServiceAbstract):
         mission_id: Union[int, str],
         size: int,
         file_count: int = 1,
-        data_type: str = None,  # Not in use
-        data_source: str = None,  # Not in use
-        s3_dir: str = None,  # Not in use
+        data_type: Optional[str] = None,  # Not in use
+        data_source: Optional[str] = None,  # Not in use
+        s3_dir: Optional[str] = None,  # Not in use
     ):
         """
         Args:
@@ -823,7 +823,7 @@ class MissionStats(ServiceAbstract):
             if not mission_id:
                 self.logger.warning("Cannot add mission data: mission_id is empty")
                 return
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 self.logger.error("Could not establish connection")
                 return
 
@@ -834,44 +834,44 @@ class MissionStats(ServiceAbstract):
                     )
 
                 if mission_id == data_buffer_key:
-                    # TODO
+                    self.machine_stats.on_data_arrive(size)
                     return
                 else:
                     mission_id = int(mission_id)
 
             self.machine_stats.on_data_arrive(size)
-            new_mission_stats = self._get_mission_stats_from_rabbitmq(mission_id)
+            # new_mission_stats = self._get_mission_stats_from_rabbitmq(mission_id)
 
-            # Update stats
-            updated_at = datetime.now(timezone.utc).isoformat()
-            try:
-                new_mission_stats["file_count"] += int(file_count)
-                new_mission_stats["data_size"] += int(size)
-                new_mission_stats["updated_at"] = updated_at
-            except Exception as e:
-                # Backword compatibility
-                new_mission_stats = {
-                    "mission_id": mission_id,
-                    "file_count": 0,
-                    "data_size": 0,
-                    "file_count_uploaded": 0,
-                    "data_size_uploaded": 0,
-                    "updated_at": None,
-                }
-                new_mission_stats["file_count"] += int(file_count)
-                new_mission_stats["data_size"] += int(size)
-                new_mission_stats["updated_at"] = updated_at
+            # Update mission stats
+            # updated_at = datetime.now(timezone.utc).isoformat()
+            # try:
+            #     new_mission_stats["file_count"] += int(file_count)
+            #     new_mission_stats["data_size"] += int(size)
+            #     new_mission_stats["updated_at"] = updated_at
+            # except Exception as e:
+            #     # Backword compatibility
+            #     new_mission_stats = {
+            #         "mission_id": mission_id,
+            #         "file_count": 0,
+            #         "data_size": 0,
+            #         "file_count_uploaded": 0,
+            #         "data_size_uploaded": 0,
+            #         "updated_at": None,
+            #     }
+            #     new_mission_stats["file_count"] += int(file_count)
+            #     new_mission_stats["data_size"] += int(size)
+            #     new_mission_stats["updated_at"] = updated_at
 
-            # Check last data mission
-            last_data_mission_id = self._get_last_data_mission_id()
-            if last_data_mission_id and last_data_mission_id != str(mission_id):
-                self._publish_stats_to_hq(last_data_mission_id)
-            self._set_last_data_mission(mission_id)
-            self._update_stats_in_rabbitmq(mission_id, new_mission_stats)
+            # # Check last data mission
+            # last_data_mission_id = self._get_last_data_mission_id()
+            # if last_data_mission_id and last_data_mission_id != str(mission_id):
+            #     self._publish_stats_to_hq(last_data_mission_id)
+            # self._set_last_data_mission(mission_id)
+            # self._update_stats_in_rabbitmq(mission_id, new_mission_stats)
 
-            self.logger.info(
-                f"Updated mission data for mission_id: {mission_id}, data_type: {data_type}, data_source: {data_source}"
-            )
+            # self.logger.info(
+            #     f"Updated mission data for mission_id: {mission_id}, data_type: {data_type}, data_source: {data_source}"
+            # )
         except Exception as e:
             self.logger.error(f"Error in on_mission_data_arrive: {str(e)}")
 
@@ -880,8 +880,8 @@ class MissionStats(ServiceAbstract):
         mission_id: Union[int, str],
         size: int,
         file_count: int = 1,
-        data_type: str = None,  # Not in use
-        data_source: str = None,  # Not in use
+        data_type: Optional[str] = None,  # Not in use
+        data_source: Optional[str] = None,  # Not in use
     ):
         """
         Update mission data statistics for a specific mission.
@@ -895,7 +895,7 @@ class MissionStats(ServiceAbstract):
         if not mission_id:
             self.logger.warning("Cannot add mission data: mission_id is empty")
             return
-        if not self._ensure_connection():
+        if not self._ensure_connection() or not self.rmq_channel:
             raise Exception("Could not establish connection")
 
         if isinstance(mission_id, str):
@@ -1040,7 +1040,7 @@ class MissionStats(ServiceAbstract):
             Current user details as a dictionary or None if not found
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             method_frame, _, body = self.rmq_channel.basic_get(
@@ -1066,7 +1066,7 @@ class MissionStats(ServiceAbstract):
         Delete the current user from RabbitMQ queue.
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             while True:
@@ -1088,7 +1088,7 @@ class MissionStats(ServiceAbstract):
             user_detail: Dictionary containing user details
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self.delete_current_user()
@@ -1228,10 +1228,11 @@ class MissionStats(ServiceAbstract):
     def __del__(self):
         """Destructor called by garbage collector to ensure resources are cleaned up, when object is about to be destroyed"""
         try:
-            self.logger.error(
-                "Destructor called by garbage collector to cleanup MissionStats"
-            )
-            self.stop()
+            if self.is_running:
+                self.logger.error(
+                    "Destructor called by garbage collector to cleanup MissionStats"
+                )
+                self.stop()
         except Exception as e:
             pass
 
