@@ -101,7 +101,8 @@ class QueueWorker(ServiceAbstract):
 
             data = message.get("data", None)
             # data = base64.b64decode(data) if message_type == "binary" else data
-            self.logger.debug(f"found data-{topic}")
+            destination_ids_str = ",".join(destination_ids)
+            self.logger.debug(f"found data-{topic}, destination_ids: [{destination_ids_str}]")
             result, remaining_dest_ids = vyom_sender_conn.send_message(
                 data, message_type, destination_ids, data_source, topic
             )
@@ -146,7 +147,8 @@ class QueueWorker(ServiceAbstract):
                 #     except Exception as e:
                 #         pass
             else:
-                self.logger.debug(f"Error: Message proccesing failed")
+                remaining_dest_ids_str = ",".join(remaining_dest_ids)
+                self.logger.debug(f"Error: Message proccesing failed topic: {topic}, remaining_dest_ids: [{remaining_dest_ids_str}]")
             return result, remaining_dest_ids
 
         except Exception as e:
