@@ -47,7 +47,7 @@ class QueueWriterJson:
         self.mission_stats = MissionStats()
         self.live_publish = True
         self.live_priority = 2
-        self.live_destinations = ["s3"]
+        self.live_destinations = ["s3", "gcs_mqtt"]
         self.expiration = "2000"  # milisecond
         self._setup_signal_handlers()
 
@@ -417,7 +417,7 @@ class QueueWriterJson:
 
                 self.logger.info(f"Data enqueued to {chunk_info_topic}")
 
-            self.mission_stats.on_mission_data_arrive(
+            self.mission_stats.(
                 mission_id=mission_id,
                 size=data_size,
                 file_count=1,
@@ -542,7 +542,7 @@ def main():
 
     try:
         writer = QueueWriterJson()
-        message_data = {"lat": 75.66666, "long": 73.0589455}
+        message_data = {"lat": 75.66666, "long": 73.0589455, "alt": 930}
         data_source = "MACHINE_POSE"  # event, warning, camera1, camera2,
         data_type = "json"  # image, binary, json
         mission_id = "111333"
@@ -570,7 +570,7 @@ def main():
 
     try:
         writer = QueueWriterJson()
-        message_data = {"lat": 75.66666, "long": 73.0589455}
+        message_data = {"lat": 75.66666, "long": 73.0589455, "alt": 930}
         data_source = "MACHINE_POSE"  # event, warning, camera1, camera2,
         data_type = "json"  # image, binary, json
         mission_id = "111333"
@@ -609,6 +609,7 @@ def main():
                 "data_id": epoch_ms,
                 "lat": 75.66666,
                 "long": 73.0589455,
+                "alt": 930,
             }
 
             data_source = "MACHINE_POSE"  # event, warning, camera1, camera2,
