@@ -645,7 +645,7 @@ class QueueWriterJson:
                     message_body = (
                         json.dumps(message_data)
                         if data_type == "json"
-                        else json.dumps(message_data)
+                        else message_data
                     )
                     headers = {
                         "message_type": "json" if data_type == "json" else "binary",
