@@ -925,324 +925,12 @@ def main():
             data_type=data_type,  # json, binary, ros
             mission_id=mission_id,  # mission_id
             priority=1,  # 1, 2
-            destination_ids=["s3"],  # ["s3"]
+            destination_ids=["gcs_mav"],  # ["s3"]
         )
     except Exception as e:
         print(f"Error writing test messages: {e}")
     finally:
         writer.cleanup()
 
-    # # Example 2, send data, live
-    from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
-
-    try:
-        writer = QueueWriterJson()
-        message_data = {"lat": 75.66666, "long": 73.0589455, "alt": 930}
-        data_source = "MACHINE_POSE"  # event, warning, camera1, camera2,
-        data_type = "json"  # image, binary, json
-        mission_id = "111333"
-
-        epoch_ms = int(time.time() * 1000)
-        uuid_padding = generate_unique_id(4)
-        filename = f"{epoch_ms}_{uuid_padding}.json"
-
-        writer.write_message(
-            message_data=message_data,  # json or binary data
-            filename=filename,  # 293749834.json, 93484934.jpg
-            data_source=data_source,  # machine_pose camera1, machine_state
-            data_type=data_type,  # json, binary, ros
-            mission_id=mission_id,  # mission_id
-            priority=1,  # 1, 2
-            destination_ids=["s3"],  # ["s3"]
-            send_live=True,
-        )
-    except Exception as e:
-        print(f"Error writing test messages: {e}")
-    finally:
-        writer.cleanup()
-
-    # # Example 3
-    from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
-
-    writer = QueueWriterJson()
-    try:
-        loop_len = 10
-        padding_length = len(str(loop_len))
-
-        for i in range(loop_len):
-            epoch_ms = int(time.time() * 1000)
-            message_data = {
-                "data": f"Test message No {i}",
-                "data_id": epoch_ms,
-                "lat": 75.66666,
-                "long": 73.0589455,
-                "alt": 930,
-            }
-
-            data_source = "MACHINE_POSE"  # event, warning, camera1, camera2,
-            data_type = "json"  # image, binary, json
-            mission_id = "111333"
-            formatted_index = str(i + 1).zfill(padding_length)
-            filename = f"{epoch_ms}_{formatted_index}.json"
-
-            writer.write_message(
-                message_data=message_data,
-                filename=filename,
-                data_source=data_source,
-                data_type=data_type,
-                mission_id=mission_id,
-                priority=1,
-                destination_ids=["s3", "gcs"],
-            )
-    except Exception as e:
-        print(f"Error writing test messages: {e}")
-    finally:
-        writer.cleanup()
-
-    # # Example 4
-    from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
-
-    writer = QueueWriterJson()
-    try:
-        import requests
-        from urllib.parse import urlparse
-
-        loop_len = 10
-        padding_length = len(str(loop_len))
-
-        # URLs for the images
-        image_urls = [
-            "https://sample-videos.com/img/Sample-jpg-image-50kb.jpg",
-            # "https://sample-videos.com/img/Sample-png-image-100kb.png",
-            # "https://sample-videos.com/img/Sample-jpg-image-100kb.jpg",
-            "https://sample-videos.com/img/Sample-jpg-image-200kb.jpg",
-            "https://sample-videos.com/img/Sample-jpg-image-500kb.jpg",
-            "https://www.sample-videos.com/video321/mp4/720/big_buck_bunny_720p_5mb.mp4",
-            "https://www.sample-videos.com/img/Sample-jpg-image-5mb.jpg",
-            "https://mirror.del.albony.in/videolan-ftp/vlc/3.0.21/macosx/vlc-3.0.21-intel64.dmg",
-            "https://www.sample-videos.com/video321/flv/360/big_buck_bunny_360p_5mb.flv",
-        ]
-
-        for i in range(loop_len):
-            epoch_ms = int(time.time() * 1000)
-            data_source = "TEST_BINARY_FILE"  # event, warning, camera1, camera2
-            data_type = "image"  # image, json, binary
-            mission_id = default_mission_id  # "34556"
-            formatted_index = str(i + 1).zfill(padding_length)
-
-            # Alternate between the two URLs
-            current_url = image_urls[i % len(image_urls)]
-
-            # Get the file extension from the URL
-            parsed_url = urlparse(current_url)
-            file_extension = parsed_url.path.split(".")[-1]
-
-            # Download the image binary data
-            response = requests.get(current_url)
-            if response.status_code == 200:
-                file_data = response.content  # This is binary data (bytes)
-
-                # Create filename with proper extension
-                filename = f"{epoch_ms}_{formatted_index}.{file_extension}"
-
-                writer.write_message(
-                    message_data=file_data,
-                    filename=filename,
-                    data_source=data_source,
-                    data_type=data_type,
-                    mission_id=mission_id,
-                    priority=1,
-                    destination_ids=["s3"],
-                    merge_chunks=True if i % 2 == 0 else False,
-                )
-            else:
-                print(
-                    f"Failed to download image from {current_url}. Status code: {response.status_code}"
-                )
-
-    except Exception as e:
-        print(f"Error writing test messages: {e}")
-    finally:
-        writer.cleanup()
-
-    # # Example 4.1 (5mb files)
-    from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
-    import time
-
-    writer = QueueWriterJson()
-    default_mission_id = "_all_"
-    try:
-        import requests
-        from urllib.parse import urlparse
-
-        loop_len = 10
-        padding_length = len(str(loop_len))
-        # URLs for the images
-        image_urls = [
-            "https://www.sample-videos.com/video321/mp4/720/big_buck_bunny_720p_5mb.mp4",
-            "https://www.sample-videos.com/img/Sample-jpg-image-5mb.jpg",
-            "https://mirror.del.albony.in/videolan-ftp/vlc/3.0.21/macosx/vlc-3.0.21-intel64.dmg",
-            "https://www.sample-videos.com/video321/flv/360/big_buck_bunny_360p_5mb.flv",
-        ]
-        for i in range(loop_len):
-            epoch_ms = int(time.time() * 1000)
-            data_source = "TEST_BINARY_FILE"  # event, warning, camera1, camera2
-            data_type = "binary"  # image, json, binary
-            mission_id = default_mission_id  # "34556"
-            formatted_index = str(i + 1).zfill(padding_length)
-            # Alternate between the two URLs
-            current_url = image_urls[i % len(image_urls)]
-            # Get the file extension from the URL
-            parsed_url = urlparse(current_url)
-            file_extension = parsed_url.path.split(".")[-1]
-            # Download the image binary data
-            response = requests.get(current_url)
-            if response.status_code == 200:
-                file_data = response.content  # This is binary data (bytes)
-                # Create filename with proper extension
-                filename = f"{epoch_ms}_{formatted_index}.{file_extension}"
-                writer.write_message(
-                    message_data=file_data,
-                    filename=filename,
-                    data_source=data_source,
-                    data_type=data_type,
-                    mission_id=mission_id,
-                    priority=1,
-                    destination_ids=["s3"],
-                    merge_chunks=True if i % 2 == 0 else False,
-                )
-            else:
-                print(
-                    f"Failed to download image from {current_url}. Status code: {response.status_code}"
-                )
-    except Exception as e:
-        print(f"Error writing test messages: {e}")
-    finally:
-        writer.cleanup()
-
-    # # Example 4.2 (10mb files)
-    from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
-    import time
-
-    default_mission_id = "_all_"
-    writer = QueueWriterJson()
-    try:
-        import requests
-        from urllib.parse import urlparse
-
-        loop_len = 10
-        padding_length = len(str(loop_len))
-        # URLs for the images
-        image_urls = [
-            "https://www.sample-videos.com/img/Sample-jpg-image-10mb.jpg",
-            "https://www.sample-videos.com/video321/3gp/144/big_buck_bunny_144p_10mb.3gp",
-            "https://www.sample-videos.com/video321/mkv/480/big_buck_bunny_480p_10mb.mkv",
-            "https://www.sample-videos.com/video321/mp4/720/big_buck_bunny_720p_10mb.mp4",
-        ]
-        for i in range(loop_len):
-            epoch_ms = int(time.time() * 1000)
-            data_source = "TEST_BINARY_FILE"  # event, warning, camera1, camera2
-            data_type = "binary"  # image, json, binary
-            mission_id = default_mission_id  # "34556"
-            formatted_index = str(i + 1).zfill(padding_length)
-            # Alternate between the two URLs
-            current_url = image_urls[i % len(image_urls)]
-            # Get the file extension from the URL
-            parsed_url = urlparse(current_url)
-            file_extension = parsed_url.path.split(".")[-1]
-            # Download the image binary data
-            response = requests.get(current_url)
-            if response.status_code == 200:
-                file_data = response.content  # This is binary data (bytes)
-                # Create filename with proper extension
-                filename = f"{epoch_ms}_{formatted_index}.{file_extension}"
-                writer.write_message(
-                    message_data=file_data,
-                    filename=filename,
-                    data_source=data_source,
-                    data_type=data_type,
-                    mission_id=mission_id,
-                    priority=1,
-                    destination_ids=["s3"],
-                    merge_chunks=True if i % 2 == 0 else False,
-                )
-            else:
-                print(
-                    f"Failed to download image from {current_url}. Status code: {response.status_code}"
-                )
-    except Exception as e:
-        print(f"Error writing test messages: {e}")
-    finally:
-        writer.cleanup()
-
-    # Example 5 - send mission detail
-    from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
-
-    writer = QueueWriterJson()
-    try:
-        mission_id = "301394"
-        machine_id = 60
-        epoch_ms = int(time.time() * 1000)
-        filename = f"{epoch_ms}.json"
-
-        mission_stats = {
-            "mission": {
-                "id": mission_id,
-                "name": f"Test Mission {mission_id}",
-                "creator_id": 1,
-                "owner_id": 1,
-                "mission_status": 1,
-                "machine_id": machine_id,
-                "mission_date": "2025-03-21",  # datetime.now(timezone.utc).strftime("%Y-%m-%d")
-                "start_time": "2025-03-21T10:00:00Z",  # datetime.now(timezone.utc).isoformat()
-                "end_time": None,  # datetime.now(timezone.utc).strftime("%Y-%m-%d")
-                # less important field
-                "description": "Testing mission navigation features",
-                "campaign_id": 1,
-                "mission_type": "",
-                "json_data": {},
-            }
-        }
-        writer.write_message(
-            message_data=mission_stats,  # json or binary data
-            filename=filename,  # 293749834.json, 93484934.jpg
-            data_source="mission_stats",  # machine_pose camera1, machine_state
-            data_type="json",  # image, binary, json
-            mission_id=mission_id,  # mission_id
-            priority=1,  # important send with priority 1
-            destination_ids=["s3"],  # ["s3"]
-        )
-    except Exception as e:
-        print(f"Error writing test messages: {e}")
-    finally:
-        writer.cleanup()
-
-    # Example 6 - send mission topics list
-    from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
-
-    writer = QueueWriterJson()
-    try:
-        mission_id = "301394"
-        epoch_ms = int(time.time() * 1000)
-        filename = f"{epoch_ms}.json"
-
-        mission_stats = {
-            "mission_topics": []  # here you have to add, mission topics object
-        }
-        writer.write_message(
-            message_data=mission_stats,  # json or binary data
-            filename=filename,  # 293749834.json, 93484934.jpg
-            data_source="mission_stats",  # machine_pose camera1, machine_state
-            data_type="json",  # image, binary, json
-            mission_id=mission_id,  # mission_id
-            priority=1,  # important send with priority 1
-            destination_ids=["s3"],  # ["s3"]
-        )
-    except Exception as e:
-        print(f"Error writing test messages: {e}")
-    finally:
-        writer.cleanup()
-
-
 if __name__ == "__main__":
     main()
