@@ -12,17 +12,19 @@ from typing import Any, Callable, Dict, Optional
 import time
 import os
 from vyomcloudbridge.utils.logger_setup import setup_logger
+from vyomcloudbridge.constants.constants import main_data_queue
 
 logger = setup_logger(name=__name__, show_terminal=False)
 
 
 class RabbitMQ:
-    def __init__(self, host: str = "localhost", queue_name: str = "data_queue"):
+    def __init__(self, host: str = "localhost", queue_name: str = main_data_queue):
         self.host = host
         self.queue_name = queue_name
         self.rmq_conn = None
         self.rmq_channel = None
         self.is_consuming = False
+        self.max_enqueue_retries = 5
         # Don't set up connection in __init__ when running as service
         # It will be set up in consume() instead
 
@@ -40,9 +42,9 @@ class RabbitMQ:
                 self.rmq_conn = pika.BlockingConnection(
                     pika.ConnectionParameters(
                         host=self.host,
-                        heartbeat=600,
-                        blocked_connection_timeout=300,
-                        socket_timeout=300,
+                        heartbeat=300,  # Reduced from 600 to 300 seconds
+                        blocked_connection_timeout=120,  # Reduced from 300 to 120
+                        socket_timeout=120,  # Reduced from 300 to 120
                     )
                 )
                 self.rmq_channel = self.rmq_conn.channel()
@@ -68,7 +70,7 @@ class RabbitMQ:
                     )
                     raise
                 logger.warning(
-                    f"RabbitMQ connection attempt {attempt + 1} failed, retrying..."
+                    f"RabbitMQ connection attempt {attempt + 1} failed AMQPConnectionError, retrying..."
                 )
                 time.sleep(2**attempt)
             except Exception as e:
@@ -113,12 +115,49 @@ class RabbitMQ:
             self.rmq_channel = None
             return False
 
+    def enqueue_message_size(
+        self,
+        size: int,  # int, string
+        queue_name: Optional[str] = None,
+        retry_count: int = 1,
+    ) -> None:
+        if not self._ensure_connection():
+            raise Exception("Could not establish connection")
+
+        if queue_name is None:
+            queue_name = "machine_buffer_array"
+
+        message = json.dumps({"size": int(size)})
+
+        try:
+            self.rmq_channel.basic_publish(
+                exchange="",
+                routing_key=queue_name,
+                body=message,
+                properties=pika.BasicProperties(delivery_mode=2),
+            )
+        except Exception as e:
+            logger.error(f"Error publishing enqueue_message_size : {e}")
+            if retry_count > self.max_enqueue_retries:
+                logger.error(
+                    f"Failed to publish enqueue_message_size after {retry_count} retries, ignoring message"
+                )
+                return
+
+            self._setup_connection()
+            self.enqueue_message_size(
+                size=size,
+                retry_count=retry_count + 1,
+            )
+
     def enqueue_message(
         self,
         message: Any,  # bytes, string, empty string
-        headers: Dict[str, Any],
+        headers: Dict[str, Any] = {},
         priority: int = 0,
         expiration: Optional[str] = None,
+        queue_name: Optional[str] = None,
+        retry_count: int = 1,
     ) -> None:
         """Publish message to queue with specified priority (0-10, higher is more priority)"""
         """ expiration is millisecond in string """
@@ -139,10 +178,13 @@ class RabbitMQ:
         if expiration is not None:
             properties["expiration"] = expiration  # 60 seconds TTL
 
+        if queue_name is None:
+            queue_name = self.queue_name
+
         try:
             self.rmq_channel.basic_publish(
                 exchange="",
-                routing_key=self.queue_name,
+                routing_key=queue_name,
                 body=message,
                 properties=pika.BasicProperties(**properties),
             )
@@ -155,12 +197,29 @@ class RabbitMQ:
 
             expiry_log = f" with expiration {expiration}ms" if expiration else ""
             logger.debug(
-                f"Enqueued message to queue {self.queue_name} with priority {priority}{expiry_log}"
+                f"Enqueued message to queue {queue_name} with priority {priority}{expiry_log}"
             )
         except Exception as e:
-            logger.error(f"Error publishing message: {e}")
+            import traceback
+
+            logger.error(
+                f"Error publishing message: {e}\n{traceback.format_exc()}, headers={headers}"
+            )
+            if retry_count > self.max_enqueue_retries:
+                logger.error(
+                    f"Failed to publish message after {retry_count} retries, ignoring message"
+                )
+                return
+
             self._setup_connection()
-            self.enqueue_message(message, priority, expiration)
+            self.enqueue_message(
+                message=message,
+                headers=headers,
+                priority=priority,
+                expiration=expiration,
+                queue_name=queue_name,
+                retry_count=retry_count + 1,
+            )
 
     def _consume_queue_message(  # Note in use
         self,
@@ -317,7 +376,7 @@ class RabbitMQ:
     def start_consume(self, callback: Callable) -> None:  # Note in use
         """Start consuming messages with priority handling by RabbitMQ"""
         # Establish initial connection
-        if not self._ensure_connection():
+        if not self._ensure_connection() or not self.rmq_channel:
             raise Exception("Could not establish initial connection")
 
         logger.info(f"Started consuming messages from {self.queue_name}...")
@@ -326,7 +385,7 @@ class RabbitMQ:
 
         while self.is_consuming:
             try:
-                if not self._ensure_connection():
+                if not self._ensure_connection() or not self.rmq_channel:
                     logger.warning("Connection lost, waiting before retry...")
                     time.sleep(1)
                     continue
@@ -382,7 +441,10 @@ class RabbitMQ:
     def __del__(self):
         """Destructor called by garbage collector to ensure resources are cleaned up, when object is about to be destroyed"""
         try:
-            logger.error("Destructor called by garbage collector to cleanup RabbitMQ")
-            self.close()
+            if self.is_healthy():
+                logger.error(
+                    "Destructor called by garbage collector to cleanup RabbitMQ"
+                )
+                self.close()
         except Exception as e:
             pass
