@@ -13,7 +13,7 @@ from typing import Callable
 import rclpy
 from rclpy.callback_groups import ReentrantCallbackGroup, MutuallyExclusiveCallbackGroup
 from rclpy.node import Node
-from rclpy.qos import QoSProfile, ReliabilityPolicy, HistoryPolicy, DurabilityPolicy
+from rclpy.qos import QoSProfile, QoSReliabilityPolicy, HistoryPolicy, QoSDurabilityPolicy
 from rosidl_runtime_py import set_message_fields
 import sensor_msgs.msg
 from std_msgs.msg import String
@@ -38,7 +38,7 @@ class SendDataToServer(Node, ServiceAbstract):
     a configuration file and handles different message types, including JSON and images.
 
     Attributes:
-        subscriber_cb_group (MutuallyExclusiveCallbackGroup): A callback group to ensure mutually exclusive callbacks.
+        callback_group (ReentrantCallbackGroup): A callback group to ensure reentrant callbacks.
         extracted_data_list (list): A list to store extracted data.
         subscribers (list): A list to store dynamically created subscribers.
         m_qos (QoSProfile): Quality of Service profile for the subscribers.
@@ -59,16 +59,23 @@ class SendDataToServer(Node, ServiceAbstract):
         ServiceAbstract.__init__(self)
 
         self.logger.info("senddatatoserver node has started.")
-        self.subscriber_cb_group = MutuallyExclusiveCallbackGroup()
+        self.callback_group = ReentrantCallbackGroup()
 
         # Initialize extracted data list
-        self.subscribers = []
+        self.machine_subscribers = []
+        self.mission_subscribers = []
 
         self.m_qos = QoSProfile(
-            reliability=ReliabilityPolicy.BEST_EFFORT,
+            reliability=QoSReliabilityPolicy.BEST_EFFORT,
             history=HistoryPolicy.KEEP_LAST,
-            depth=10,
-            durability=DurabilityPolicy.VOLATILE,
+            depth=50,
+            durability=QoSDurabilityPolicy.VOLATILE,
+        )
+        self.camera_qos = QoSProfile(
+            reliability=QoSReliabilityPolicy.RELIABLE,
+            history=HistoryPolicy.KEEP_ALL,
+            depth=100,
+            durability=QoSDurabilityPolicy.VOLATILE,
         )
 
         self.writer = QueueWriterJson()
@@ -83,47 +90,122 @@ class SendDataToServer(Node, ServiceAbstract):
 
         # ros topic used to trigger updation of subscriber list
         self.topic_list_sub = self.create_subscription(
-            String, "update_topic_list", self.update_topic_list_callback, 10
+            String, "update_topic_list", self.update_topic_list_machine_callback, 10
         )
         self.topic_list_sub
+        
+        self.topic_list_sub_os = self.create_subscription(
+            String, "update_topic_list_os", self.update_topic_list_mission_callback, 10
+        )
+        self.topic_list_sub_os
+        
         self._freq_tracker = defaultdict(lambda: {"last_time": None})
-
-    def update_topic_list_callback(self, msg):
-        # Get new topic list
-        new_topic_list = self.get_subcribed_topics()
-        self.logger.debug(f"Received new topic list: {new_topic_list}")
-
-        new_topics = {topic["topic"] for topic in new_topic_list}
-        current_subscriber_map = {sub.topic_name: sub for sub in self.subscribers}
-        current_topics = set(current_subscriber_map.keys())
-
-        # Early exit if no changes
-        if current_topics == new_topics:
-            self.logger.debug("Topic list unchanged. No update needed.")
+        self.logger.info("SendDataToServer node initialized successfully.")
+           
+    def update_topic_list_mission_callback(self, msg):
+        try:
+            # Parse JSON array from message
+            new_topics_list = json.loads(msg.data)
+            if not isinstance(new_topics_list, list):
+                self.logger.error("Expected a JSON list of topic objects.")
+                return
+        except json.JSONDecodeError as e:
+            self.logger.error(f"Failed to parse JSON from /update_topic_list_os: {e}")
             return
 
+        self.logger.info(f"Received new_topics mission: {new_topics_list}")
+        available_topics = self.load_topic_list_from_file()
+
+        # Build the final list of topics we will subscribe to
+        updated_subscription_list = []
+        for received_topic in new_topics_list:
+            matching_topic_config = next(
+                (topic for topic in available_topics if topic["name"] == received_topic["name"]),
+                None
+            )
+            if matching_topic_config:
+                # Override stored settings with any provided in the incoming message
+                matching_topic_config.update({
+                    "is_subscribed": received_topic.get("is_subscribed", matching_topic_config["is_subscribed"]),
+                    "frequency": received_topic.get("frequency", matching_topic_config["frequency"]),
+                    "send_live": received_topic.get("send_live", matching_topic_config["send_live"]),
+                    "save_locally": received_topic.get("save_locally", matching_topic_config["save_locally"])
+                })
+                updated_subscription_list.append(matching_topic_config)
+        
+        new_topics = {topic["topic"] for topic in updated_subscription_list}
+        self.logger.info(f"Received new_topics mission: {new_topics}")
+        
+        
+        # Get current mission_subscribers
+        current_subscriber_map = {sub.topic_name: sub for sub in self.mission_subscribers}
+        current_topics = set(current_subscriber_map.keys())
+
+        # # Early exit if no changes
+        if current_topics == new_topics:
+            self.logger.info("Topic list unchanged. No update needed.")
+            return
+
+        self.logger.info(f"New topics: {new_topics}, Current topics: {current_topics}")
         # Build the new subscriber list before destroying any
-        self.subscribers = [
-            sub for sub in self.subscribers if sub.topic_name in new_topics
+        self.mission_subscribers = [
+            sub for sub in self.mission_subscribers if sub.topic_name in new_topics
         ]
 
         # Unsubscribe from topics that are no longer needed
         for topic_name in current_topics - new_topics:
-            self.logger.debug(f"Unsubscribing from topic: {topic_name}")
+            self.logger.info(f"Unsubscribing from topic: {topic_name}")
+            self.destroy_subscription(current_subscriber_map[topic_name])
+
+        self.logger.info(f"Subscribing to new topic: ")
+        
+        # Subscribe to new topics
+        for topic in updated_subscription_list:
+            if topic["topic"] not in current_topics:
+                self.logger.info(
+                    f"Subscribing to new topic: "
+                    f"{topic['name']} | {topic['data_type']} | {topic['topic']} | "
+                    f"live: {topic['send_live']} | freq: {topic['frequency']} | save: {topic['save_locally']}"
+                )
+                self.create_dynamic_subscribers(topic, self.mission_subscribers)
+                
+
+    def update_topic_list_machine_callback(self, msg):
+        new_topic_list = self.get_subcribed_topics()
+        self.logger.info(f"[Machine] Received new topic list: {new_topic_list}")
+
+        new_topics = {topic["topic"] for topic in new_topic_list}
+        current_subscriber_map = {sub.topic_name: sub for sub in self.machine_subscribers}
+        current_topics = set(current_subscriber_map.keys())
+        
+
+        # Early exit if no changes
+        if current_topics == new_topics:
+            self.logger.debug("[Machine] Topic list unchanged. No update needed.")
+            return
+
+        # Build the new subscriber list before destroying any
+        self.machine_subscribers = [
+            sub for sub in self.machine_subscribers if sub.topic_name in new_topics
+        ]
+
+        # Unsubscribe from topics that are no longer needed
+        for topic_name in current_topics - new_topics:
+            self.logger.debug(f"[Machine] Unsubscribing from topic: {topic_name}")
             self.destroy_subscription(current_subscriber_map[topic_name])
 
         # Subscribe to new topics
         for topic in new_topic_list:
             if topic["topic"] not in current_topics:
-                self.logger.debug(f"Subscribing to new topic: {topic['topic']}")
-                self.create_dynamic_subscribers(topic)
+                self.logger.debug(f"[Machine] Subscribing to new topic: {topic['topic']}")
+                self.create_dynamic_subscribers(topic, self.machine_subscribers)
 
     def create_subscribers(self):
         self.is_running = True
         self.logger.debug(f"topics {self.get_subcribed_topics()}")
         for topic in self.get_subcribed_topics():
             self.logger.info(f"Subscribing to topic: {topic}")
-            self.create_dynamic_subscribers(topic)
+            self.create_dynamic_subscribers(topic,self.machine_subscribers)
 
     def get_subcribed_topics(self):
         """
@@ -169,6 +251,20 @@ class SendDataToServer(Node, ServiceAbstract):
 
     def send_summary(self, summary):
         self.logger.debug(f"Summary {summary}")
+        
+        self.writer.write_message(
+            message_data=summary,
+            data_type="json",
+            data_source="mission_summary",
+            destination_ids=["gcs_mav"],
+            filename=None,
+            mission_id=self.mission_id,
+            project_id=None,
+            priority=3,
+            merge_chunks=True,
+            expiry_time_ms=5000,
+            background=True
+        )
 
         self.writer.write_message(
             message_data=summary,
@@ -181,6 +277,7 @@ class SendDataToServer(Node, ServiceAbstract):
             priority=3,
             merge_chunks=True,
             send_live=True,
+            background=True
         )
 
     def update_mission_id(self):
@@ -197,10 +294,10 @@ class SendDataToServer(Node, ServiceAbstract):
         if self.current_mission.get("mission_status") == 2:
             if self.summariser.get_mission_mode() == 1:
                 self.logger.debug("stopped")
-                self.summariser.print_summary()
-                self.send_summary(self.summariser.print_summary())
-                self.summariser.set_mission_mode(2)
-                self.summariser.reset()
+                # self.summariser.print_summary()
+                # self.send_summary(self.summariser.print_summary())
+                # self.summariser.set_mission_mode(2)
+                # self.summariser.reset()
 
         return default_mission_id
 
@@ -220,7 +317,9 @@ class SendDataToServer(Node, ServiceAbstract):
 
         # eg: f_msg_data_type=vyom_mission_msgs.msg.MissionStatus, f_topic_name=MISSION_TOPIC
         def callback(msg):
-            self.summariser.update(f_topic, msg)
+            if self.current_mission.get("mission_status") == 1:
+                self.logger.debug("Mission is in progress, updating summariser")
+                self.summariser.update(f_topic, msg)
 
             self.logger.debug(f"Ros data processing for ros_topic: {f_topic_name}")
 
@@ -237,20 +336,19 @@ class SendDataToServer(Node, ServiceAbstract):
                 current_value = converter.convert(f_msg_data_type, 1, msg)
 
                 cleaned_value = self.replace_nan_with_null(current_value)
+                epoch_ms = int(time.time() * 1000)
 
-                now = time.time()
-                epoch_ms = int(now * 1000)
-
-                if f_msg_data_type == "sensor_msgs.msg.Image":
+                if (f_msg_data_type == "sensor_msgs.msg.Image" and f_msg_data_type.__module__ == "sensor_msgs.msg.Image"):
                     filename = f"{epoch_ms}.jpeg"
                     data_type = "image"
                     extracted_data = cleaned_value
                 else:
                     filename = f"{epoch_ms}.json"
                     data_type = "json"
-
-                    timestamp_sec = int(now)
-                    timestamp_nsec = int((now - timestamp_sec) * 1_000_000_000)
+                    
+                    timenow = time.time()
+                    timestamp_sec = int(timenow)
+                    timestamp_nsec = int((timenow - timestamp_sec) * 1_000_000_000)
 
                     extracted_data = {
                         "timestamp": {
@@ -284,6 +382,18 @@ class SendDataToServer(Node, ServiceAbstract):
                             json.dump(extracted_data, file)
 
                 else:
+                    self.logger.info(f"Sending data for: {f_topic_name}")
+                    success, error = self.writer.write_message(
+                        message_data=extracted_data,  # json data
+                        filename=filename,  # nullable or epoch time
+                        data_source=f_topic_name,  # telemetry, mission_summary
+                        data_type=data_type,  # file, video, image
+                        mission_id=self.mission_id,  # mission_id
+                        priority=1,  # 1  for velocity data, battery topic, and ROS data
+                        destination_ids=["s3"],  # ["s3"]
+                        merge_chunks=True,  # True for telemetry data
+                        send_live=f_send_live,
+                    )
                     self.writer.write_message(
                         message_data=extracted_data,  # json data
                         filename=filename,  # nullable or epoch time
@@ -291,10 +401,23 @@ class SendDataToServer(Node, ServiceAbstract):
                         data_type=data_type,  # file, video, image
                         mission_id=self.mission_id,  # mission_id
                         priority=1,  # 1  for velocity data, battery topic, and ROS data
-                        destination_ids=["gcs_mqtt", "s3"],  # ["s3"] ["gcs_mqtt" via mqtt]
+                        destination_ids=["gcs_mqtt"],  # ["s3"] ["gcs_mqtt" via mqtt]
                         merge_chunks=True,  # True for telemetry data
+                        send_persistent=False,
                         send_live=f_send_live,
                     )
+                    if success:
+                        self.logger.debug(
+                            f"Successlly sent to S3 {success} for topic: {f_topic_name}"
+                        )
+                    elif error:
+                        self.logger.error(
+                            f"Not sent to S3. Error {error} for topic: {f_topic_name}"
+                        )
+                    else:
+                        self.logger.info(
+                            f"Not sent to S3. Status unknown for topic: {f_topic_name}"
+                        )
                 self.logger.info(f"Ros data processed for ros_topic: {f_topic_name}")
 
         return callback
@@ -328,7 +451,7 @@ class SendDataToServer(Node, ServiceAbstract):
 
         return getattr(module, class_name)
 
-    def create_dynamic_subscribers(self, f_topic):
+    def create_dynamic_subscribers(self, f_topic,f_subscribers):
         """
         Dynamically creates and adds a subscriber to the list of subscribers.
         This method takes a topic configuration, creates a subscription for the
@@ -341,20 +464,23 @@ class SendDataToServer(Node, ServiceAbstract):
                 - "name" (str): The name of the topic.
         """
         try:
-            self.subscribers.append(
+            if "camera" in f_topic['topic'].lower():
+                qos_profile = self.camera_qos
+            else:
+                qos_profile = self.m_qos
+                
+            f_subscribers.append(
                 self.create_subscription(
                     self.import_class_from_string(f_topic["data_type"]),
                     f_topic["topic"],
                     self.create_listener_function(
                         f_topic["data_type"], f_topic["name"], f_topic["topic"], f_topic["send_live"], f_topic["frequency"], f_topic["save_locally"]
                     ),
-                    self.m_qos,
-                    callback_group=self.subscriber_cb_group,
+                    callback_group=self.callback_group,
+                    qos_profile=qos_profile,
                 )
             )
-            self.logger.info(
-                f"Subscribed to topic: {f_topic['topic']} with type: {f_topic['data_type']}"
-            )
+            self.logger.info(f"Subscribed to topic: {f_topic['topic']} with type: {f_topic['data_type']}")
         except Exception as e:
             self.logger.error(
                 f"Failed to subscribe to topic: {f_topic['topic']} with type: {f_topic['data_type']}. Error: {e}"
@@ -366,10 +492,10 @@ class SendDataToServer(Node, ServiceAbstract):
         self.logger.info("Shutting down all subscribers.")
 
         # Explicitly destroy all subscriptions
-        for subscriber in self.subscribers:
+        for subscriber in self.machine_subscribers:
             self.destroy_subscription(subscriber)
 
-        self.subscribers.clear()
+        self.machine_subscribers.clear()
 
     def start(self):
         pass
@@ -403,7 +529,6 @@ class RosPublisher(ServiceAbstract):
             self.is_running = True
 
             self.send_data_to_server.create_subscribers()
-
             def start_proccess():
                 rclpy.spin(self.send_data_to_server)
                 while self.is_running:
@@ -451,13 +576,10 @@ def main(args=None):
     data_streamer = RosPublisher()
     try:
         data_streamer.start()
-
         time.sleep(100)
-
     finally:
         data_streamer.stop()
     print("Completed SendDataToServer service example")
 
-
 if __name__ == "__main__":
-    main()
+    main()
\ No newline at end of file
