@@ -452,11 +452,15 @@ class MissionUtils:
 
 def main():
     # Example 1: Interective start and end mission
+    from vyomcloudbridge.utils.mission_utils import MissionUtils
     mission_utils = MissionUtils()
+    new_mission_id = mission_utils.generate_mission_id()
+    print("Trying to start mission_id with-", new_mission_id)
     try:
         try:
             mission_start_time = datetime.now(timezone.utc).isoformat()
             mission_detail, start_mission_error = mission_utils.start_mission(
+                id = new_mission_id,
                 start_time=mission_start_time,
                 destination_ids=["s3", "gcs_mqtt"],
             )
